@@ -1,6 +1,6 @@
 __author__ = "Shane Drabing"
 __license__ = "MIT"
-__version__ = "0.0.5"
+__version__ = "0.0.6"
 __email__ = "shane.drabing@gmail.com"
 
 
@@ -19,7 +19,7 @@ import selenium.webdriver
 from selenium.webdriver.common.keys import Keys
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.support.ui import WebDriverWait as WDW
-
+from selenium.common.exceptions import NoSuchElementException
 
 # CONSTANTS
 
@@ -74,7 +74,7 @@ class Screpe:
             return list(exe.map(f, *args))
 
     @staticmethod
-    def wait_for(f, limit=10):
+    def wait_until(f, limit=10):
         start = time.time()
         while not f():
             if start + limit < time.time():
@@ -151,7 +151,102 @@ class Screpe:
 
         return self.cache[key]
 
-    # METHODS (REQUESTS)
+    # METHODS (BASE SELENIUM)
+
+    def driver_launch(self):
+        # lazy import
+        if "webdriver_manager" not in globals():
+            import webdriver_manager.firefox
+
+        # silent logging
+        os.environ["WDM_LOG_LEVEL"] = "0"
+
+        # options
+        opts = selenium.webdriver.firefox.options.Options()
+        opts.add_argument("--headless")
+
+        # install driver
+        gdm = webdriver_manager.firefox.GeckoDriverManager
+        path = gdm(print_first_line=False).install()
+
+        # assign driver to instance
+        self.driver = selenium.webdriver.Firefox(
+            executable_path=path, options=opts)
+
+    def driver_close(self):
+        if self.driver is not None:
+            self.driver.close()
+
+    def driver_restart(self):
+        self.driver_close()
+        self.driver_launch()
+
+    def driver_id(self):
+        return self.driver.find_element(_BY_XPATH, "html").id
+
+    def driver_loaded(self):
+        return self._id != self.driver_id()
+
+    # FUNCTIONS (BROWSING)
+
+    def open(self, url):
+        if self.driver is None:
+            self.driver_launch()
+        self.halt()
+        self.bide(lambda: self.driver.get(url))
+
+    def source(self):
+        if self.driver is None:
+            return
+        return self.cook(self.driver.page_source)
+
+    def bide(self, expr):
+        self._id = self.driver_id()
+        expr()
+        self.wait_until(self.driver_loaded)
+
+    def select(self, selector):
+        try:
+            self._node = self.driver.find_element(_BY_SELECTOR, selector)
+            return self._node
+        except NoSuchElementException:
+            pass
+
+    def wait_and_select(self, selector):
+
+        def f():
+            node = screpe.select(selector)
+            if node is None:
+                time.sleep(_PAUSE)
+                return False
+            return True
+
+        screpe.wait_until(f)
+        return screpe.select(selector)
+
+    def click(self, selector):
+        self._node = self.select(selector)
+        self._node.click()
+        return self._node
+
+    def send_keys(self, message):
+        if self._node is not None:
+            self._node.send_keys(message)
+
+    def send_enter(self):
+        self.send_keys(Keys.ENTER)
+
+    def send_tab(self):
+        self.send_keys(Keys.TAB)
+
+    # METHODS (REQUESTING)
+
+    def browse(self, url):
+        self.open(url)
+        return self.source()
+
+    def browse_many(self, urls):
+        return list(map(self.browse, urls))
 
     def dine(self, url):
         expr = lambda: self.halt() or self.get(url)
@@ -179,78 +274,3 @@ class Screpe:
         self.halt()
         dfs = pandas.read_html(url)
         dfs[which].to_csv(fpath, index=index)
-
-    # METHODS (SELENIUM)
-
-    def driver_launch(self):
-        # lazy import
-        if "webdriver_manager" not in globals():
-            import webdriver_manager.firefox
-
-        # silent logging
-        os.environ["WDM_LOG_LEVEL"] = "0"
-
-        # options
-        opts = selenium.webdriver.firefox.options.Options()
-        opts.add_argument("--headless")
-
-        # install driver
-        gdm = webdriver_manager.firefox.GeckoDriverManager
-        path = gdm(print_first_line=False).install()
-
-        # assign driver to instance
-        self.driver = selenium.webdriver.Firefox(
-            executable_path=path, options=opts)
-
-    def driver_close(self):
-        if self.driver is not None:
-            self.driver.close()
-
-    def driver_restart(self):
-        driver_close()
-        driver_launch()
-
-    def driver_id(self):
-        return self.driver.find_element(_BY_XPATH, "html").id
-
-    def driver_loaded(self):
-        return self._id != self.driver_id()
-
-    def open(self, url):
-        if self.driver is None:
-            self.driver_launch()
-        self.halt()
-        self.bide(lambda: self.driver.get(url))
-
-    def source(self):
-        if self.driver is None:
-            return
-        return self.cook(self.driver.page_source)
-
-    def graze(self, url):
-        self.open(url)
-        return self.source()
-
-    def bide(self, expr):
-        self._id = self.driver_id()
-        expr()
-        self.wait_for(self.driver_loaded)
-
-    def select(self, selector):
-        self._node = self.driver.find_element(_BY_SELECTOR, selector)
-        return self._node
-
-    def click(self, selector):
-        self._node = self.select(selector)
-        self._node.click()
-        return self._node
-
-    def send_keys(self, message):
-        if self._node is not None:
-            self._node.send_keys(message)
-
-    def send_enter(self):
-        self.send_keys(Keys.ENTER)
-
-    def send_tab(self):
-        self.send_keys(Keys.TAB)
